
/*
 * UART.c
 *
 *  Created on: Dec 18, 2013
 *      Author: B46911
 */
#include "UART.h"

/**********************************************************************************************
* External objects
**********************************************************************************************/


/**********************************************************************************************
* Global variables
**********************************************************************************************/
pt2FuncU8 Uart_Callback;


/**********************************************************************************************
* Constants and macros
**********************************************************************************************/


/**********************************************************************************************
* Local types
**********************************************************************************************/


/**********************************************************************************************
* Local function prototypes
*********************************************************************************************/
void UART0_IRQHandler (void);

/**********************************************************************************************
* Local variables
**********************************************************************************************/


/**********************************************************************************************
* Local functions
**********************************************************************************************/


/**********************************************************************************************
* Global functions
**********************************************************************************************/


/***********************************************************************************************
*
* @brief    Uart_Init - Initalizes the Uart0 to run at 9600 bauds assuming bus clock of 20Mhz
* @param    none
* @return   none
*
************************************************************************************************/  
void UART_Init()
{
	SIM->SCGC |=  SIM_SCGC_UART0_MASK;		/* Enable bus clock in UART0*/
	UART0->BDH = 0;							/* One stop bit*/
	UART0->BDL = 128;						/* Baud rate at 9600*/
	UART0->C1  = 0;							/* No parity enable,8 bit format*/
	UART0->C2 |= UART_C2_TE_MASK;			/* Enable Transmitter*/
	UART0->C2 |= UART_C2_RE_MASK;			/* Enable Receiver*/
	UART0->C2 |= UART_C2_RIE_MASK;			/* Enable Receiver interrupts*/
	

}

/***********************************************************************************************
*
* @brief    Uart_SetCallback - Set a callback function to execute when a byte is received on the Uart0
* @param    pointer to function with an UINT8 argument
* @return   none
*
************************************************************************************************/  
void Uart_SetCallback(pt2FuncU8 ptr)
{
	Uart_Callback = ptr;	
}


/***********************************************************************************************
*
* @brief    Uart_SendChar - Send a single byte on Uart0 
* @param    byte to send
* @return   none
*
************************************************************************************************/  
void Uart_SendChar(UINT8 send)
{
	while((UART0->S1&UART_S1_TDRE_MASK)==0);		/* Wait for transmit buffer to be empty*/
	(void)UART0->S1;								/* Read UART0_S1 register*/
	UART0->D=send;								/* Send data*/
}

/***********************************************************************************************
*
* @brief    Uart_GetChar - Retrieve the received char from the Uart0 buffer (should be called from Interrupt) 
* @param    none
* @return   received byte
*
************************************************************************************************/  
UINT8 Uart_GetChar()
{
	
  UINT8 recieve;
  while(( UART0->S1 & UART_S1_RDRF_MASK)==0);	/* Wait for received buffer to be full*/
  (void) UART0->S1;								/* Read UART0_S1 register*/
  recieve= UART0->D;								/* Read received data*/
  return recieve;

} 

/***********************************************************************************************
*
* @brief    UART0_IRQHandler - Uart0 reception interrupt, calls the user defined callback function 
* @param    none
* @return   none
*
************************************************************************************************/
void UART0_IRQHandler ()
{

	(void)UART0->S1;		/* Clear reception flag mechanism*/
	Uart_Callback(Uart_GetChar());

}
